<?php defined('BASEPATH') OR exit('No direct script access allowed');

class Category extends MY_Controller {

	public function __construct() {

		parent::__construct();

		auth_check(); // check login auth

		$this->rbac->check_module_access();

		$this->load->model('admin/Category_model', 'category');

		$this->load->model('admin/Common_model', 'common');

	}

	//-----------------------------------------------------------

	public function index() {

		$this->load->view('admin/includes/_header');

		$this->load->view('admin/category/category_list');

		$this->load->view('admin/includes/_footer');

	}

	public function datatable_json() {

		$data['categories'] = $this->category->get_all_category();

		// $data['categories']=$this->common->getRecords('fx_category','','',array('category_id'=>'ASC'));

		$data['arrD'] = $arrD = $this->category->getDepthArray($data['categories'], "parent_id", 'category_id');

		$data = array();

		$i = 0;

		if (count($arrD) > 0) {

			foreach ($arrD as $d) {

				if ($d["depth"]) {
					$d["categoryTitle"] = str_repeat("&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;", $d["depth"]) . "|&rArr; " . $d["categoryTitle"];
				}

				$status = ($d['is_active'] == 1) ? 'checked' : '';

				$data[] = array(

					++$i,

					stripslashes($d['categoryTitle']),

					stripslashes($d['created_at']),

					'<div class="custom-control custom-switch">

	        		<input type="checkbox" class="tgl_checkbox custom-control-input" id="cb_' . $d['category_id'] . '"

					data-id="' . $d['category_id'] . '"

					id="cb_' . $d['category_id'] . '"

					' . $status . '><label class="custom-control-label" for="cb_' . $d['category_id'] . '"></label></div>',

					// <a title="View" class="view btn btn-primary-rgba" href="' . base_url('admin/category/edit/' . $d['category_id']) . '"> <i class="feather icon-eye"></i></a>

					'<a title="Edit" class="update btn btn-success-rgba" href="' . base_url('admin/category/edit/' . $d['category_id']) . '"> <i class="feather icon-edit-2"></i></a>

					<a title="Delete" class="delete btn btn-danger-rgba" href=' . base_url("admin/category/delete/" . $d['category_id']) . ' title="Delete" onclick="return confirm(\'Do you want to delete ?\')"> <i class="feather icon-trash"></i></a>',

				);

			}

		}

		$records['data'] = $data;

		echo json_encode($records);

	}

	//-----------------------------------------------------------

	function change_status() {

		$this->category->change_status();

	}

	public function add() {

		$this->rbac->check_operation_access(); // check opration permission

		$categoriesarr = $this->common->getRecords('fx_category', '');

		$data['categories'] = $this->category->getTreeDD($categoriesarr, "category_id", "categoryTitle", "parent_id", '');

		if ($this->input->post('submit')) {

			$this->form_validation->set_rules('categoryTitle', 'Category Title', 'trim|required');

			$this->form_validation->set_rules('description', 'Category Description', 'trim|required');

			$this->form_validation->set_rules('metaTitle', 'Meta Title', 'trim|required');

			$this->form_validation->set_rules('metaKeyword', 'Meta Keyword', 'trim|required');

			$this->form_validation->set_rules('metaDesc', 'Meta Description', 'trim|required');

			if ($this->form_validation->run()) {
				$config = array(
					'upload_path' => 'uploads/category/',
					'allowed_types' => 'jpg|jpeg|gif|png',
					'file_name' => rand(1, 9999),
					'max_size' => 0,
				);
				// $this->upload->initialize($config);
				$this->load->library('upload',$config);

				if ($_FILES['category_image']['name'] != '') {
					if ($this->upload->do_upload('category_image')) {
						$dt = $this->upload->data();
						$_POST['category_image'] = $dt['file_name'];
					} else {
						$_POST['category_image'] = $_POST['old_category_image'];
						$data['error'] = $this->upload->display_errors();

					}
				}
				$data_array = array(

					'categoryTitle' => $this->input->post('categoryTitle'),
					'category_image' => $_POST['category_image'],
					'parent_id' => $this->input->post('parent_id'),

					'description' => $this->input->post('description'),

					'metaTitle' => $this->input->post('metaTitle'),

					'metaKeyword' => $this->input->post('metaKeyword'),

					'metaDesc' => $this->input->post('metaDesc'),

					'xOrder' => $this->input->post('xOrder'),

					'created_at' => date('Y-m-d : h:m:s'),

				);

				$data_array = $this->security->xss_clean($data_array);

				$result = $this->category->add_category($data_array);

				if ($result) {

					$this->session->set_flashdata('success', 'Category has been added successfully!');

					redirect(base_url('admin/category'));

				}

			} else {

				$this->load->view('admin/includes/_header');

				$this->load->view('admin/category/category_add', $data);

				$this->load->view('admin/includes/_footer');

			}

		} else {

			$this->load->view('admin/includes/_header');

			$this->load->view('admin/category/category_add', $data);

			$this->load->view('admin/includes/_footer');

		}

	}

	public function edit($id = 0) {

		$this->rbac->check_operation_access(); // check opration permission

		$data['fetchValue'] = $this->common->getRecords('fx_category', array('category_id' => $id));

		$data['maincategories'] = $this->common->getRecords('fx_category', array('category_id' => $id));

		$categoriesarr = $this->common->getRecords('fx_category', array('is_active' => 1));

		$data['categories'] = $this->category->getTreeDD($categoriesarr, "category_id", "categoryTitle", "parent_id", $data['maincategories'][0]['parent_id']);

		// echo "<pre>";print_r($data['categories']);exit;

		if ($this->input->post('submit')) {

			$this->form_validation->set_rules('categoryTitle', 'Category Title', 'trim|required');

			$this->form_validation->set_rules('description', 'Category Description', 'trim|required');

			$this->form_validation->set_rules('metaTitle', 'Meta Title', 'trim|required');

			$this->form_validation->set_rules('metaKeyword', 'Meta Keyword', 'trim|required');

			$this->form_validation->set_rules('metaDesc', 'Meta Description', 'trim|required');

			if ($this->form_validation->run()) {
				$config = array(
					'upload_path' => 'uploads/category',
					'allowed_types' => 'jpg|jpeg|gif|png',
					'file_name' => rand(1, 9999),
					'max_size' => 0,
				);
				// $this->upload->initialize($config);
				$this->load->library('upload',$config);
				if ($_FILES['category_image']['name'] != '') {

					if ($this->upload->do_upload('category_image')) {
						$dt = $this->upload->data();
						$data_array['category_image'] = $dt['file_name'];
					} else {

						$data_array['category_image'] = $_POST['old_category_image'];
						$data['error'] = $this->upload->display_errors();
					}
				} else {
					$data_array['category_image'] = $_POST['old_category_image'];
					$data['error'] = $this->upload->display_errors();
				}
				/*echo "<pre>";
				print_r($data_array);*/
				$data_array = array(
					'category_image' => $data_array['category_image'],
					'categoryTitle' => $this->input->post('categoryTitle'),

					'parent_id' => $this->input->post('parent_id'),

					'description' => $this->input->post('description'),

					'metaTitle' => $this->input->post('metaTitle'),

					'metaKeyword' => $this->input->post('metaKeyword'),

					'metaDesc' => $this->input->post('metaDesc'),

					'xOrder' => $this->input->post('xOrder'),

					'updated_at' => date('Y-m-d : h:m:s'),

				);
				/*echo "<pre>";
				print_r($_FILES);*/
				$data_array = $this->security->xss_clean($data_array);
				/*echo "<pre>";
					print_r($data_array);
				*/
				$result = $this->category->edit_category($data_array, $id);

				if ($result) {

					$this->session->set_flashdata('success', 'Category has been added successfully!');

					redirect(base_url('admin/category'));

				}

			} else {

				$this->load->view('admin/includes/_header');

				$this->load->view('admin/category/category_edit', $data);

				$this->load->view('admin/includes/_footer');

			}

		} else {

			$data['category'] = $this->category->get_user_by_id($id);

			$this->load->view('admin/includes/_header');

			$this->load->view('admin/category/category_edit', $data);

			$this->load->view('admin/includes/_footer');

		}

	}

	public function delete($id = 0) {

		$this->rbac->check_operation_access(); // check opration permission

		$this->db->delete('fx_category', array('category_id' => $id));

		$this->session->set_flashdata('success', 'Use has been deleted successfully!');

		redirect(base_url('admin/category'));

	}

}

?>